/*
 *  RoombaComm Interface Test
 *
 *
 *  Copyright (c) 2005 Tod E. Kurt, tod@todbot.com
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General
 *  Public License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *  Boston, MA  02111-1307  USA
 *
 */


package roombacomm;


public class Test {

  static boolean debug = false;
  static boolean nopoweroff = false;

  public static void main(String[] args) {
    if( args.length == 0 ) {
      System.out.println("RoombaCommTest <serialportname>");
      System.exit(0);
    }

    for( int i=0; i<args.length; i++ ) {
      if( args[i].compareTo("-d") == 0) {
        debug = true;
      }
      else if( args[i].compareTo("-p") == 0 ) {
        nopoweroff = true;
      }
    }

    String portname = args[args.length-1];  // e.g. "/dev/cu.KeySerial1"

    RoombaComm roombacomm = new RoombaCommSerial();

    roombacomm.debug = debug;

    String portlist[] = roombacomm.listPorts();
    System.err.println("Available ports:");
    for( int i=0; i<portlist.length; i++ )
      System.err.println("  "+i+": "+portlist[i]);

    if( ! roombacomm.connect( portname ) ) {
      System.err.println("Couldn't connect to "+portname);
      System.exit(1);
    }
    
    System.err.println("Roomba startup");
    roombacomm.startup();
    
    System.err.println("Checking for Roomba... ");
    if( roombacomm.updateSensors() ) {
      System.err.println("Roomba found!");
    } else {
      System.err.println("No Roomba. :(");
    }

    System.err.println("Playing some notes");
    roombacomm.playNote( 72, 10 );
    roombacomm.pause( 200 );
    roombacomm.playNote( 79, 10 );
    roombacomm.pause( 200 );
    roombacomm.playNote( 76, 10 );
    roombacomm.pause( 200 );

    if( !nopoweroff ) {
      System.err.println("Powering off in 1 second.");
      roombacomm.pause( 1000 );
      roombacomm.powerOff();
    }

    System.err.println("Disconnecting");
    roombacomm.disconnect();

    System.err.println("Done");
  }


}
